@@ -69,6 +69,8 @@ from google.cloud.asset_v1.types.assets import IamPolicyAnalysisState
 from google.cloud.asset_v1.types.assets import IamPolicySearchResult
 from google.cloud.asset_v1.types.assets import RelatedAsset
 from google.cloud.asset_v1.types.assets import RelatedAssets
+from google.cloud.asset_v1.types.assets import RelatedResource
+from google.cloud.asset_v1.types.assets import RelatedResources
 from google.cloud.asset_v1.types.assets import RelationshipAttributes
 from google.cloud.asset_v1.types.assets import Resource
 from google.cloud.asset_v1.types.assets import ResourceSearchResult
@@ -125,6 +127,8 @@ __all__ = (
     "IamPolicySearchResult",
     "RelatedAsset",
     "RelatedAssets",
+    "RelatedResource",
+    "RelatedResources",
     "RelationshipAttributes",
     "Resource",
     "ResourceSearchResult",
