@@ -62,6 +62,8 @@ from .assets import (
     IamPolicySearchResult,
     RelatedAsset,
     RelatedAssets,
+    RelatedResource,
+    RelatedResources,
     RelationshipAttributes,
     Resource,
     ResourceSearchResult,
@@ -117,6 +119,8 @@ __all__ = (
     "IamPolicySearchResult",
     "RelatedAsset",
     "RelatedAssets",
+    "RelatedResource",
+    "RelatedResources",
     "RelationshipAttributes",
     "Resource",
     "ResourceSearchResult",
